==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/transform/ExportCommand.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2018 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/**
 * API Status: **Private**
 * @module nmodule/webEditors/rc/transform/ExportCommand
 */
define(['lex!webEditors', 'dialogs', 'Promise', 'underscore', 'bajaux/commands/Command', 'nmodule/webEditors/rc/fe/feDialogs', 'nmodule/webEditors/rc/transform/config/ExportDialog', 'nmodule/webEditors/rc/transform/exportUtils', 'nmodule/webEditors/rc/util/textUtils'], function (lexs, dialogs, Promise, _, Command, feDialogs, ExportDialog, exportUtils, textUtils) {
  'use strict';

  var subjectToDisplay = textUtils.subjectToDisplay;
  var _lexs = _slicedToArray(lexs, 1),
    webEditorsLex = _lexs[0];

  /**
   * Command for exporting a given object.
   *
   * @class
   * @extends {module:bajaux/commands/Command}
   * @alias module:nmodule/webEditors/rc/transform/ExportCommand
   */
  var ExportCommand = /*#__PURE__*/function (_Command) {
    /**
     * @param {*} subject the subject to be exported
     */
    function ExportCommand(subject) {
      var _this;
      _classCallCheck(this, ExportCommand);
      _this = _callSuper(this, ExportCommand, [{
        module: 'webEditors',
        lex: 'commands.export',
        func: function func() {
          return _this.readExportConfig().then(function (config) {
            return config && _this.doExport(config)["catch"](function (error) {
              //This catch is specific to the 'doExport' because 'readExportConfig' has its own catch handling in feDialog which shows an
              // error dialog, then rejects so we don't want to see the same error twice in two different dialogs.
              feDialogs.error(error);
            });
          });
        }
      }]);
      _this.$subject = subject;
      return _this;
    }

    /**
     * Prompt the user for configuration details about their export operation.
     * @returns {Promise.<module:nmodule/webEditors/rc/transform/config/ExportDialog~ExportConfig>}
     */
    _inherits(ExportCommand, _Command);
    return _createClass(ExportCommand, [{
      key: "readExportConfig",
      value: function readExportConfig() {
        var subject = this.$subject;
        return subjectToDisplay(subject).then(function (display) {
          return feDialogs.showFor({
            title: webEditorsLex.get('commands.export.dialog.title', display),
            value: subject,
            type: ExportDialog
          });
        });
      }

      /**
       * Perform the export operation using the user's selected configuration.
       * @param {module:nmodule/webEditors/rc/transform/config/ExportDialog~ExportConfig} config
       * @returns {Promise}
       */
    }, {
      key: "doExport",
      value: function doExport(config) {
        var transformOp = config.transformOp,
          destination = config.destination,
          destContext = config.destContext,
          exportContext = config.exportContext;
        var cx = _.extend({}, destContext, exportContext);
        var transformerSupplier = exportUtils.isTransformerSupplier(transformOp);
        return Promise["try"](function () {
          return transformerSupplier ? destination.prepare(transformOp, cx) : true;
        }).then(function (shouldWrite) {
          if (shouldWrite) {
            var promise = transformerSupplier ? destination.transform(transformOp, cx) : transformOp.doTransform(cx);
            dialogs.showLoading(500, promise);
            return promise;
          }
        });
      }
    }]);
  }(Command);
  return ExportCommand;
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/transform/ExportCommand.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2018 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/**
 * API Status: **Private**
 * @module nmodule/webEditors/rc/transform/ExportCommand
 */
define(['lex!webEditors', 'dialogs', 'Promise', 'underscore', 'bajaux/commands/Command', 'nmodule/webEditors/rc/fe/feDialogs', 'nmodule/webEditors/rc/transform/config/ExportDialog', 'nmodule/webEditors/rc/transform/exportUtils', 'nmodule/webEditors/rc/util/textUtils'], function (lexs, dialogs, Promise, _, Command, feDialogs, ExportDialog, exportUtils, textUtils) {
  'use strict';

  var subjectToDisplay = textUtils.subjectToDisplay;
  var _lexs = _slicedToArray(lexs, 1),
    webEditorsLex = _lexs[0];

  /**
   * Command for exporting a given object.
   *
   * @class
   * @extends {module:bajaux/commands/Command}
   * @alias module:nmodule/webEditors/rc/transform/ExportCommand
   */
  var ExportCommand = /*#__PURE__*/function (_Command) {
    /**
     * @param {*} subject the subject to be exported
     */
    function ExportCommand(subject) {
      var _this;
      _classCallCheck(this, ExportCommand);
      _this = _callSuper(this, ExportCommand, [{
        module: 'webEditors',
        lex: 'commands.export',
        func: function func() {
          return _this.readExportConfig();
        }
      }]);
      _this.$subject = subject;
      return _this;
    }

    /**
     * Prompt the user for configuration details about their export operation.
     * @returns {Promise.<module:nmodule/webEditors/rc/transform/config/ExportDialog~ExportConfig>}
     */
    _inherits(ExportCommand, _Command);
    return _createClass(ExportCommand, [{
      key: "readExportConfig",
      value: function readExportConfig() {
        var _this2 = this;
        var subject = this.$subject;
        return subjectToDisplay(subject).then(function (display) {
          return feDialogs.showFor({
            title: webEditorsLex.get('commands.export.dialog.title', display),
            value: subject,
            type: ExportDialog,
            buttons: {
              ok: function ok(dlg, evt, ed) {
                return ed.read().then(function (config) {
                  return config && _this2.doExport(config, dlg).then(function () {
                    return _this2.$saveExportDialog(ed);
                  })["catch"](function (error) {
                    //This catch is specific to the 'doExport' because 'readExportConfig' has its own catch handling in feDialog which shows an
                    // error dialog, then rejects so we don't want to see the same error twice in two different dialogs.
                    feDialogs.error(error);
                  });
                });
              },
              cancel: function cancel() {
                return false;
              }
            }
          });
        });
      }

      /**
       * @private
       * @param {module:nmodule/webEditors/rc/transform/config/ExportDialog} exportDialog
       * @returns {Promise}
       */
    }, {
      key: "$saveExportDialog",
      value: function $saveExportDialog(exportDialog) {
        return exportDialog.save();
      }

      /**
       * Perform the export operation using the user's selected configuration.
       * @param {module:nmodule/webEditors/rc/transform/config/ExportDialog~ExportConfig} config
       * @param {Dialog} dialog
       * @returns {Promise}
       */
    }, {
      key: "doExport",
      value: function doExport(config, dialog) {
        var transformOp = config.transformOp,
          destination = config.destination,
          destContext = config.destContext,
          exportContext = config.exportContext;
        var cx = _.extend({}, destContext, exportContext);
        var transformerSupplier = exportUtils.isTransformerSupplier(transformOp);
        return Promise["try"](function () {
          return transformerSupplier ? destination.prepare(transformOp, cx) : true;
        }).then(function (shouldWrite) {
          if (shouldWrite) {
            var promise = transformerSupplier ? destination.transform(transformOp, cx) : transformOp.doTransform(cx);
            dialogs.showLoading(500, promise);
            return promise;
          }
          //User choice is to not overwrite the file, keep open the current dialog
          dialog.keepOpen();
        });
      }
    }]);
  }(Command);
  return ExportCommand;
});
